/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Figure 1 (part 1)
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2009
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////

local mymax=450
local mymin=50
local mywidth=20


count if kcpe_self_recent<=`mymax' & kcpe_self_recent>=`mymin' & has_score==1
local N_`mymax'_`mymin'_self=r(N)
hist kcpe_self_recent if kcpe_self_recent<=`mymax' & kcpe_self_recent>=`mymin' & has_score==1, ///
     xscale(range(`mymin'(50)`mymax')) xlabel(`mymin'(50)`mymax') lc(white) lw(vvthin) width(`mywidth') start(`mymin') freq ///
	 ytitle("Frequency of self-reported KCPE scores") ///
     scheme(s1mono) legend(rows(1)) ///
     note("KLPS2 data, N=`N_`mymax'_`mymin'_self'") xline(250)


count if kcpe_confirmed_first<=`mymax' & kcpe_confirmed_first>=`mymin' & has_score==1
local N_`mymax'_`mymin'_truefirst=r(N)
hist kcpe_confirmed_first if kcpe_confirmed_first<=`mymax' & kcpe_confirmed_first>=`mymin' & has_score==1, ///
     xscale(range(`mymin'(50)`mymax')) xlabel(`mymin'(50)`mymax') lc(white) lw(vvthin) width(`mywidth') start(`mymin') freq ///
	 ytitle("Frequency of confirmed KCPE scores") ///
     scheme(s1mono) legend(rows(1)) ///
     note("KLPS2 data, N=`N_`mymax'_`mymin'_truefirst', restricted to confirmed first KCPE scores") xline(250)
