/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Figure 1 (part 2)
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2010
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////

set seed 1234567

// SELF-REPORTED SCORES
   
// in case DCdensity command has been run recently:
cap drop Xj
cap drop Yj
cap drop r0
cap drop fhat
cap drop se_fhat
// install McCrary's (and Kovac's) DCdensity in your ado/personal directory so that this command will work (type sysdir to know where)
DCdensity kcpe_self_recent if abs(kcpe_self_recent-250)<200, breakpoint(250) generate(Xj Yj r0 fhat se_fhat) b(5) 
// gather info for graph note
return list
di r(theta)/r(se)
di normal(r(theta)/r(se))
di 2*(1-normal(abs(r(theta))/r(se)))
local thisp=2*(1-normal(abs(r(theta))/r(se)))
local thispSTR=string(round(`thisp',0.001),"%5.3f")
if "`thispSTR'"=="0.000" {
 local thispSTR="<0.001"
}
else {
 local thispSTR="=`thispSTR'"
}
cap drop _hi
qui gen _hi = fhat + 1.96*se_fhat
cap drop _lo
qui gen _lo = fhat - 1.96*se_fhat
gr twoway (scatter Yj Xj if Xj<450, msymbol(circle_hollow) mcolor(gray))           ///
   (line fhat r0 if r0 < 250, lcolor(black) lwidth(medthick))   ///
   (line fhat r0 if r0 > 250 & r0<450, lcolor(black) lwidth(medthick))   ///
   (line _hi r0 if r0 < 250, lcolor(black) lwidth(vthin))              ///
   (line _lo r0 if r0 < 250, lcolor(black) lwidth(vthin))              ///
   (line _hi r0 if r0 > 250 & r0<450, lcolor(black) lwidth(vthin))              ///
   (line _lo r0 if r0 > 250 & r0<450, lcolor(black) lwidth(vthin)),             ///
   xline(250, lcolor(black)) legend(off) ///
   scheme(s1mono) note("Density discontinuity p`thispSTR'")
   
   
// CONFIRMED FIRST SCORES

// in case DCdensity command has been run recently:
cap drop Xj
cap drop Yj
cap drop r0
cap drop fhat
cap drop se_fhat

// install McCrary's (and Kovac's) DCdensity in your ado/personal directory so that this command will work (type sysdir to know where)
DCdensity kcpe_confirmed_first if abs(kcpe_confirmed_first-250)<200, breakpoint(250) generate(Xj Yj r0 fhat se_fhat) b(5) 
// gather info for graph note
return list
di r(theta)/r(se)
di normal(r(theta)/r(se))
di 2*(1-normal(abs(r(theta))/r(se)))
local thisp=2*(1-normal(abs(r(theta))/r(se)))
local thispSTR=string(round(`thisp',0.001),"%5.3f")
if "`thispSTR'"=="0.000" {
 local thispSTR="<0.001"
}
else {
 local thispSTR="=`thispSTR'"
}
cap drop _hi
qui gen _hi = fhat + 1.96*se_fhat
cap drop _lo
qui gen _lo = fhat - 1.96*se_fhat
// rebuild graph
gr twoway (scatter Yj Xj, msymbol(circle_hollow) mcolor(gray))           ///
   (line fhat r0 if r0 < 250, lcolor(black) lwidth(medthick))   ///
   (line fhat r0 if r0 > 250, lcolor(black) lwidth(medthick))   ///
   (line _hi r0 if r0 < 250, lcolor(black) lwidth(vthin))              ///
   (line _lo r0 if r0 < 250, lcolor(black) lwidth(vthin))              ///
   (line _hi r0 if r0 > 250, lcolor(black) lwidth(vthin))              ///
   (line _lo r0 if r0 > 250, lcolor(black) lwidth(vthin)),             ///
   xline(250, lcolor(black)) legend(off) ///
   scheme(s1mono) note("Density discontinuity p`thispSTR'")
