/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Figure 2
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2010
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////


// fix a window of data over which to carry out this optimization
local fixedbandwidth=0.7 


gen r2kt=.
forvalues f=0/1 {
  gen r2f`f'yALL=.
  gen df`f'yALL=.
}
local r2counter=0


// looping over possible offsets
local lowerloopbound -50
local upperloopbound 50
forvalues i=`lowerloopbound'/`upperloopbound' {
  local r2counter=`r2counter'+1
  di "Now at `i', looping from `lowerloopbound' to `upperloopbound' (counter `r2counter')"
  quietly {
  cap drop tkt
  cap drop tp
  cap drop itktp
  gen tkt=round(kcpe_confirmed_first_scaled-`i'/100,0.00001)
  gen tp=tkt>0
  gen itktp=tkt*tp
  replace r2kt=`i'/100 in `r2counter'
  // note: limit bandwidth of kcpe_confirmed_first_scaled rather than tkt so that it's the same variation trying to be explained in any case.
  forvalues f=0/1 {
    reg finishsecondary tp tkt itktp if abs(kcpe_confirmed_first_scaled)<`fixedbandwidth' & female==`f' , vce(cluster tkt)
    replace r2f`f'yALL=e(r2) in `r2counter' if _b[tp]>0
    replace df`f'yALL=_b[tp] in `r2counter'
  }	
  } // quietly
}
forvalues f=0/1 {
  egen maxr2f`f'yALL=max(r2f`f'yALL)
  sum r2kt df`f'yALL if maxr2f`f'yALL==r2f`f'yALL
  tab r2kt df`f'yALL if maxr2f`f'yALL==r2f`f'yALL
}

keep r2* kcpe_confirmed_first_scaled female
//this save is so that the file does not have to be re-run in its entirety
//if you simply want to re-draw the graph differently
save cmr-temp.dta, replace



// continue with graphing
use cmr-temp.dta, clear


forvalues f=0/1 {
 sum r2f`f'yALL
 local ycoordf`f'=r(max)
 sum r2kt if r2f`f'yALL==r(max)
 local xcoordf`f'=round(r(mean),0.01)*100+250 // times 100 and plus 250 to scale back to regular KCPE axes
 local equivf`f'=250+round(100*r(mean))
}

gen r2kt250=250+round(r2kt*100)

twoway (line  r2f0yALL r2kt250, xlabel(200(10)300) lc(black)) ///
       (line  r2f1yALL r2kt250, xlabel(200(10)300) lc(gray) lp(-)), ///
       scheme(s1mono) legend(rows(1) label(1 Male) label(2 Female)) xtitle(Possible discontinuities) ytitle(R squared) ///
	   text(`ycoordf0' `xcoordf0' " `equivf0'", place(e)) ///
	   text(`ycoordf1' `xcoordf1' " `equivf1'", place(e))


