/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Figure 3
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2010
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////

gen graphd=.
gen graphdplus=.
gen graphdminus=.
gen graphx=.

local widthstep=4
local steps=34

forvalues i=1/`steps' {
  local abskt`i'=(2*`i'+1)*`widthstep'/200
  local minbin=floor((250-`i')/`widthstep')
  local maxbin=floor((250+`i'-1)/`widthstep')

  // linear regression for discontinuity and CI
  qui reg finishsecondary passrkcpe rkcpe int_pass_rkcpe if abs(rkcpe)<`abskt`i'' , vce(cluster rkcpe)
  local disco`i'=_b[passrkcpe]
  local dplus`i'=_b[passrkcpe]+1.96*_se[passrkcpe]
  local dminus`i'=_b[passrkcpe]-1.96*_se[passrkcpe]

  quietly {
  replace graphd=`disco`i'' in `i'
  replace graphdplus=`dplus`i'' in `i'
  replace graphdminus=`dminus`i'' in `i'
  replace graphx=`abskt`i'' in `i'
  }
}

twoway (rarea  graphdminus graphdplus graphx if graphx>=0.1 & graphx<=1.2, fc(gs11) lc(white)) ///
       (line graphd graphx if graphx>=0.1 & graphx<=1.2, lc(black) lp(-)), ///
	   scheme(s1mono) yline(0) legend(order(2 1) label(2 Estimated discontinuity) label(1 95 percent C.I.)) ///
	   xtitle(Sample restriction: bandwidth about discontinuity) ytitle(Change in P[completing secondary]) xlabel(0.2(0.2)1.2)

sum graphd if graphx>=0.1 & graphx<=1.2, det 
local thismax=r(max)
local thismin=r(min)
local strthismin=string(`thismin',"%4.2g")
local strthismax=string(`thismax',"%4.2g")
di "values `thismin' `thismax'"
di "[rounded] Estimates range from `strthismin' to `strthismax'"
