/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Figure 4
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2009
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////

local bw=0.8 

sort rkcpe
local b8str="_b8"
local imin=-`bw'
local imax=`bw'-0.1

// bin means for scattering
gen kcpeavg=.
gen probavg=.
gen probfatheravg=.
gen probmotheravg=.
gen probageavg=.
local loopcounter=0
forvalues i=`imin'(0.1)`imax' {
  local loopcount=`loopcount'+1
  qui sum rkcpe if rkcpe>=`i' & rkcpe<(`i'+0.1) & rkcpe!=.
  qui replace kcpeavg=r(mean) in `loopcount'
  qui sum female if rkcpe>=`i' & rkcpe<(`i'+0.1) & rkcpe!=.
  qui replace probavg=r(mean) in `loopcount'
  qui sum fathers_education if rkcpe>=`i' & rkcpe<(`i'+0.1) & rkcpe!=.
  qui replace probfatheravg=r(mean) in `loopcount'
  qui sum mothers_education if rkcpe>=`i' & rkcpe<(`i'+0.1) & rkcpe!=.
  qui replace probmotheravg=r(mean) in `loopcount'
  qui sum age_at_klps2_approximate if rkcpe>=`i' & rkcpe<(`i'+0.1) & rkcpe!=.
  qui replace probageavg=r(mean) in `loopcount'
}
label var probavg "10-point bin average"
label var probfatheravg "10-point bin average"
label var probmotheravg "10-point bin average"
label var probageavg "10-point bin average"

// regressions for quadratic graphs
reg female passrkcpe rkcpe int_pass_rkcpe rkcpe2 int_pass_rkcpe2  if abs(rkcpe)<`bw' , vce(cluster rkcpe)
predict pfemale, xb
local t_female=string(abs(_b[passrkcpe]/_se[passrkcpe]),"%6.3g")
local p_female=string(2*ttail(e(df_r),abs(_b[passrkcpe]/_se[passrkcpe])),"%6.3g")
label var pfemale "Quadratic Probability"
	   
reg fathers_education passrkcpe rkcpe int_pass_rkcpe rkcpe2 int_pass_rkcpe2  if abs(rkcpe)<`bw' , vce(cluster rkcpe)
predict anyprobfather, xb
local t_fathered=string(abs(_b[passrkcpe]/_se[passrkcpe]),"%6.3g")
local p_fathered=string(2*ttail(e(df_r),abs(_b[passrkcpe]/_se[passrkcpe])),"%6.3g")
label var anyprobfather "Quadratic Regression"

reg mothers_education passrkcpe rkcpe int_pass_rkcpe rkcpe2 int_pass_rkcpe2  if abs(rkcpe)<`bw' , vce(cluster rkcpe)
predict anyprobmother, xb
local t_mothered=string(abs(_b[passrkcpe]/_se[passrkcpe]),"%6.3g")
local p_mothered=string(2*ttail(e(df_r),abs(_b[passrkcpe]/_se[passrkcpe])),"%6.3g")
label var anyprobmother "Quadratic Regression"

reg age_at_klps2_approximate passrkcpe rkcpe int_pass_rkcpe rkcpe2 int_pass_rkcpe2  if abs(rkcpe)<`bw' , vce(cluster rkcpe)
predict anyprobage, xb
local t_age=string(abs(_b[passrkcpe]/_se[passrkcpe]),"%6.3g")
local p_age=string(2*ttail(e(df_r),abs(_b[passrkcpe]/_se[passrkcpe])),"%6.3g")
label var anyprobage "Quadratic Regression"

// adding a line manually
gen vertical=.
gen horizontal=.
replace horizontal=0 in 1/2 
replace vertical=0 in 1
replace vertical=1 in 2
label var vertical "Cutoff value"

// counts
count if abs(rkcpe)<`bw' & female!=.
local N_BW_female=r(N)
count if abs(rkcpe)<`bw' & fathers_education!=. 
local N_BW_father=r(N)
count if abs(rkcpe)<`bw' & mothers_education!=. 
local N_BW_mother=r(N)
count if abs(rkcpe)<`bw' & age_at_klps2_approximate!=. 
local N_BW_age=r(N)


// BEGIN GRAPHING

// changing a line manually
replace vertical=15 in 2

twoway (line anyprobfather rkcpe if abs(rkcpe)<`bw' & rkcpe<0, lc(black)) ///
       (line anyprobfather rkcpe if abs(rkcpe)<`bw' & rkcpe>=0, lc(black)) ///
       (line vertical horizontal, lc(black) lw(medthick) lp(.##)) ///
       (scatter probfatheravg kcpeavg, msym(Oh) mc(black) ), ///
       scheme(s1mono) ///
       xtitle("KCPE score") ytitle("Father Education") legend(rows(1) order(1 4 3) size(small)) ///
       note("KLPS2 data, N=`N_BW_father', Discontinuity T=`t_fathered' (p=`p_fathered')")

// changing a line manually
replace vertical=15 in 2

twoway (line anyprobmother rkcpe if abs(rkcpe)<`bw' & rkcpe<0, lc(black)) ///
       (line anyprobmother rkcpe if abs(rkcpe)<`bw' & rkcpe>=0, lc(black)) ///
       (line vertical horizontal, lc(black) lw(medthick) lp(.##)) ///
       (scatter probmotheravg kcpeavg, msym(Oh) mc(black) ), ///
       scheme(s1mono) ///
       xtitle("KCPE score") ytitle("Mother Education") legend(rows(1) order(1 4 3) size(small)) ///
       note("KLPS2 data, N=`N_BW_mother', Discontinuity T=`t_mothered' (p=`p_mothered')")

// changing a line manually
replace vertical=1 in 2

twoway (line pfemale rkcpe if abs(rkcpe)<`bw' & pfemale>=0 & pfemale<=1 & rkcpe<0, lc(black)) ///
       (line pfemale rkcpe if abs(rkcpe)<`bw' & pfemale>=0 & pfemale<=1 & rkcpe>=0, lc(black)) ///
       (line vertical horizontal, lc(black) lw(medthick) lp(.##)) ///
       (scatter probavg kcpeavg, msym(Oh) mc(black) ), ///
       scheme(s1mono) /// 
       xtitle("KCPE score") ytitle("Percent Female") legend(rows(1) order(1 4 3) size(small)) ///
       note("KLPS2 data, N=`N_BW_female', Discontinuity T=`t_female' (p=`p_female')")

	   // changing a line manually
replace vertical=15 in 1
replace vertical=30 in 2

twoway (line anyprobage rkcpe if abs(rkcpe)<`bw' & rkcpe<0, lc(black)) ///
       (line anyprobage rkcpe if abs(rkcpe)<`bw' & rkcpe>=0, lc(black)) ///
       (line vertical horizontal, lc(black) lw(medthick) lp(.##)) ///
       (scatter probageavg kcpeavg, msym(Oh) mc(black) ), ///
       scheme(s1mono) ///
       xtitle("KCPE score") ytitle("Age") legend(rows(1) order(1 4 3) size(small)) ///
       note("KLPS2 data, N=`N_BW_age', Discontinuity T=`t_age' (p=`p_age')")
