/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Figure 5
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2009
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////

local bw=0.8


gen cdfgrade=.
label var cdfgrade "Highest level (year/grade) of education"

// setting up main graph
gen cdfdiff=.
gen cdfupper=.
gen cdflower=.
label var cdfdiff "CDF Difference"
label var cdfupper "95% C.I."
label var cdflower "95% C.I."

// these are for setting up male/female graphs
gen cdfFdiff=.
gen cdfFupper=.
gen cdfFlower=.
label var cdfFdiff "CDF Difference (Female)"
label var cdfFupper "95% C.I."
label var cdfFlower "95% C.I."
gen cdfMdiff=.
gen cdfMupper=.
gen cdfMlower=.
label var cdfMdiff "CDF Difference (Male)"
label var cdfMupper "95% C.I."
label var cdfMlower "95% C.I."


forvalues i=7/16 {
  // setting up main graph
  gen ed_le_`i'=max_grade_complete<=`i' if abs(rkcpe)<`bw' & rkcpe!=.
  reg ed_le_`i' passrkcpe rkcpe int_pass_rkcpe if abs(rkcpe)<`bw', vce(cluster rkcpe)
  local b`i'=_b[passrkcpe]
  local upper`i'=_b[passrkcpe]+2*_se[passrkcpe]
  local lower`i'=_b[passrkcpe]-2*_se[passrkcpe]

  // these commands are for setting up male/female graphs
  reg ed_le_`i' passrkcpe rkcpe int_pass_rkcpe if abs(rkcpe)<`bw' & female==1, vce(cluster rkcpe)
  local bF`i'=_b[passrkcpe]
  local upperF`i'=_b[passrkcpe]+2*_se[passrkcpe]
  local lowerF`i'=_b[passrkcpe]-2*_se[passrkcpe]
  reg ed_le_`i' passrkcpe rkcpe int_pass_rkcpe if abs(rkcpe)<`bw' & female==0, vce(cluster rkcpe)
  local bM`i'=_b[passrkcpe]
  local upperM`i'=_b[passrkcpe]+2*_se[passrkcpe]
  local lowerM`i'=_b[passrkcpe]-2*_se[passrkcpe]

}

////////////////////////////////////////////////////////////////////
// actual CDF difference figure with confidence intervals.
// a la duflo 2000 fig 8, duflo 2001 fig 2

forvalues i=7/16 {
 quietly {
  replace cdfgrade=`i' in `i'  
  replace cdfdiff=-`b`i'' in `i'  
  replace cdfupper=-`upper`i'' in `i'
  replace cdflower=-`lower`i'' in `i'
  replace cdfFdiff=-`bF`i'' in `i'  
  replace cdfFupper=-`upperF`i'' in `i'
  replace cdfFlower=-`lowerF`i'' in `i'
  replace cdfMdiff=-`bM`i'' in `i'  
  replace cdfMupper=-`upperM`i'' in `i'
  replace cdfMlower=-`lowerM`i'' in `i'
 } // quietly
}

twoway (scatter cdfdiff cdfgrade, connect(l) lc(black) msymbol(O) msize(medsmall) mc(black)) ///
       (line cdfupper cdfgrade, lc(black) lp(-)) ///
       (line cdflower cdfgrade, lc(black) lp(-)), ///
       legend(order(1 2)) ///
       title("CDF Difference, piecewise linear, small bandwidth, no other controls", size(medsmall)) ///
       scheme(s1mono) yline(0, lc(black) lw(medthin)) ///
       ylabel(-0.05(0.05)0.25,labsize(small)) xlabel(0(2)20,labsize(small)) ytitle(Difference in CDF)

// use commands analogous to above to make male-only or female-only graphs