/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Figure 6 (part 4)
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2010
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////


local absmax=0.8

gen roundedrkcpe=round(rkcpe-0.0499999,0.1)
gen roundedrkcpeP5=roundedrkcpe+0.05

local thisoutcome="pregnant_by_18"
local thistitle="Probability of Pregnancy by Age 18"
keep if female==1 & age_at_klps2_approximate>=18 // KEEP/DROP LINE SPECIFIC TO THIS OUTCOME

// be aware of this feature of floating point numbers:
//
// . di (0.2-0.05)-0.15
// 2.776e-17
// 
// . di (0.3-0.05)-0.25
// 0


bys roundedrkcpe: egen binmeanoutcome=mean(`thisoutcome')
label var binmeanoutcome "Ten-point bins "

reg `thisoutcome' passrkcpe rkcpe int_pass_rkcpe if abs(rkcpe)<`absmax', vce(cluster rkcpe)
predict piecewiselinearfit, xb
label var piecewiselinearfit "Piecewise linear prediction"
gen lolcifs=.
gen hilcifs=.

forvalues i=150(1)249 {
 quietly {
  lincom _cons+((`i'-250)/100)*rkcpe
  replace hilcifs=r(estimate)+invttail(r(df),0.025)*r(se) if round(rkcpe-(`i'-250)/100,0.0001)==0
  replace lolcifs=r(estimate)-invttail(r(df),0.025)*r(se) if round(rkcpe-(`i'-250)/100,0.0001)==0
 }
}
forvalues i=250(1)350 {
 quietly {
  lincom _cons+((`i'-250)/100)*rkcpe+((`i'-250)/100)*int_pass_rkcpe+passrkcpe
  replace hilcifs=r(estimate)+invttail(r(df),0.025)*r(se) if round(rkcpe-(`i'-250)/100,0.0001)==0
  replace lolcifs=r(estimate)-invttail(r(df),0.025)*r(se) if round(rkcpe-(`i'-250)/100,0.0001)==0
 }
}


sort rkcpe

gen vertical=.
gen horizontal=.
replace horizontal=0 in 1/2 // alternative scaling might read 250
replace vertical=0 in 1 // these values vary from file to file
replace vertical=0.3 in 2 // these values vary from file to file
label var vertical "Cutoff value"

twoway (rarea lolcifs hilcifs rkcpe if rkcpe<-0.0099 & abs(rkcpe)<`absmax', lw(none) color(gs10)) ///
       (rarea lolcifs hilcifs rkcpe if rkcpe>=-0.0001 & abs(rkcpe)<`absmax', lw(none) color(gs10)) ///
       (line piecewiselinearfit rkcpe if rkcpe<0 & abs(rkcpe)<`absmax', lc(black)) ///
       (line piecewiselinearfit rkcpe if rkcpe>=0 & rkcpe<=1.5 & abs(rkcpe)<`absmax', lc(black)) ///
	   (line vertical horizontal, lc(black) lw(medthick) lp(.##)) ///
       (scatter binmeanoutcome roundedrkcpeP5 if abs(rkcpe)<`absmax', msym(Oh) mc(black)), ///
       scheme(s1mono) xlabel(-1(0.25)1) ///
       xtitle("KCPE score (normalized so that cutoff=0)") ytitle("`thistitle'") ///
	   legend(rows(1) order(3 1 6) label(1 "95% CI") size(small)) ///
       note("KLPS2 data; dots are midpoints of 10-point bins")


