/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Table 3
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2008
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////



local absmax=0.8
local mainspec="passrkcpe rkcpe int_pass_rkcpe female"
local olsspec="finishsecondary rkcpe int_pass_rkcpe female"
local ivspec="(finishsecondary=passrkcpe) rkcpe int_pass_rkcpe female"
tab psdp_std98 , gen(ds)

local controls1="age_at_klps2_approximate ds2-ds6"
local controls2="mothers_education_0_if_missing missing_mothers_education"
local controls3="fathers_education_0_if_missing missing_fathers_education"
local ctrls="`controls1' `controls2' `controls3'"
local nm="ravens_plus_vocab_standardized!=."
local oldest2="psdp_std98>5"

// PANEL A

// column 1
local outcome="ravens_plus_vocab_standardized"
reg `outcome' `olsspec' if abs(rkcpe)<`absmax', vce(cluster rkcpe)

// column 2
reg `outcome' `olsspec' `ctrls' if abs(rkcpe)<`absmax', vce(cluster rkcpe)

// column 3
ivregress 2sls `outcome' `ivspec' if abs(rkcpe)<`absmax', vce(cluster rkcpe)
qui reg finishsecondary `mainspec' if `outcome'!=. & abs(rkcpe)<`absmax', vce(cluster rkcpe)
test passrkcpe=0

// column 4
ivregress 2sls `outcome' `ivspec' `ctrls' if abs(rkcpe)<`absmax', vce(cluster rkcpe)
qui reg finishsecondary `mainspec' `ctrls' if `outcome'!=. & abs(rkcpe)<`absmax', vce(cluster rkcpe)
test passrkcpe=0

// column 5
local outcome="vocabulary_standardized"
ivregress 2sls `outcome' `ivspec' `ctrls' if abs(rkcpe)<`absmax' & `nm', vce(cluster rkcpe)
qui reg finishsecondary `mainspec' `ctrls' if abs(rkcpe)<`absmax' & `nm', vce(cluster rkcpe)
test passrkcpe=0

// column 6
local outcome="ravens_standardized"
ivregress 2sls `outcome' `ivspec' `ctrls' if abs(rkcpe)<`absmax' & `nm', vce(cluster rkcpe)
qui reg finishsecondary `mainspec' `ctrls' if abs(rkcpe)<`absmax' & `nm', vce(cluster rkcpe)
test passrkcpe=0


// PANEL B

// column 1
local outcome="ravens_plus_vocab_standardized"
reg `outcome' `olsspec' if abs(rkcpe)<`absmax' & `oldest2', vce(cluster rkcpe)

// column 2
reg `outcome' `olsspec' `ctrls' if abs(rkcpe)<`absmax' & `oldest2', vce(cluster rkcpe)

// column 3
ivregress 2sls `outcome' `ivspec' if abs(rkcpe)<`absmax' & `oldest2', vce(cluster rkcpe)
qui reg finishsecondary `mainspec' if `outcome'!=. & abs(rkcpe)<`absmax' & `oldest2', vce(cluster rkcpe)
test passrkcpe=0

// column 4
ivregress 2sls `outcome' `ivspec' `ctrls' if abs(rkcpe)<`absmax' & `oldest2', vce(cluster rkcpe)
qui reg finishsecondary `mainspec' `ctrls' if `outcome'!=. & abs(rkcpe)<`absmax' & `oldest2', vce(cluster rkcpe)
test passrkcpe=0

// column 5
local outcome="vocabulary_standardized"
ivregress 2sls `outcome' `ivspec' `ctrls' if abs(rkcpe)<`absmax' & `nm' & `oldest2', vce(cluster rkcpe)
qui reg finishsecondary `mainspec' `ctrls' if abs(rkcpe)<`absmax' & `nm' & `oldest2', vce(cluster rkcpe)
test passrkcpe=0

// column 6
local outcome="ravens_standardized"
ivregress 2sls `outcome' `ivspec' `ctrls' if abs(rkcpe)<`absmax' & `nm' & `oldest2', vce(cluster rkcpe)
qui reg finishsecondary `mainspec' `ctrls' if abs(rkcpe)<`absmax' & `nm' & `oldest2', vce(cluster rkcpe)
test passrkcpe=0
