/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Table 4, cols 3 and 4
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2009
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////



local absmax=0.8
local mainspecshort="passrkcpe rkcpe int_pass_rkcpe"
local olsspecshort="finishsecondary rkcpe int_pass_rkcpe"
local ivspecshort="(finishsecondary=passrkcpe) rkcpe int_pass_rkcpe"
tab psdp_std98 , gen(ds)

local controls1="age_at_klps2_approximate ds2-ds6"
local controls2="mothers_education_0_if_missing missing_mothers_education"
local controls3="fathers_education_0_if_missing missing_fathers_education"
local ctrls="`controls1' `controls2' `controls3'"

local bandwidth "abs(rkcpe)<`absmax'"
local oldermale "female==0 & psdp_std98>5"
local female18 "female==1 & age_at_klps2_approximate>=18"


// PANEL A ROW 1

local outcome "employed"

// 3
ivprobit `outcome' `ivspecshort' if `bandwidth' & `oldermale' , vce(cluster rkcpe)
version 10.1: margins, dydx(finishsecondary) predict(p)
qui reg finishsecondary `mainspecshort' if `bandwidth' & `oldermale' , vce(cluster rkcpe)
test passrkcpe=0

// 4
ivprobit `outcome' `ivspecshort' `ctrls' if `bandwidth' & `oldermale' , vce(cluster rkcpe)
version 10.1: margins, dydx(finishsecondary) predict(p)
qui reg finishsecondary `mainspecshort' `ctrls' if `bandwidth' & `oldermale' , vce(cluster rkcpe)
test passrkcpe=0



// PANEL A ROW 2

local outcome "self_employed"


// 3
ivprobit `outcome' `ivspecshort' if `bandwidth' & `oldermale' , vce(cluster rkcpe)
version 10.1: margins, dydx(finishsecondary) predict(p)
qui reg finishsecondary `mainspecshort' if `bandwidth' & `oldermale' , vce(cluster rkcpe)
test passrkcpe=0

// 4
ivprobit `outcome' `ivspecshort' `ctrls' if `bandwidth' & `oldermale' , vce(cluster rkcpe)
version 10.1: margins, dydx(finishsecondary) predict(p)
qui reg finishsecondary `mainspecshort' `ctrls' if `bandwidth' & `oldermale' , vce(cluster rkcpe)
test passrkcpe=0




// PANEL B ROW 1

local outcome "pregnant_by_18"

// 3
ivprobit `outcome' `ivspecshort' if `bandwidth' & `female18', vce(cluster rkcpe)
version 10.1: margins, dydx(finishsecondary) predict(p)
qui reg finishsecondary `mainspecshort' if `bandwidth' & `female18' , vce(cluster rkcpe)
test passrkcpe=0

// 4
ivprobit `outcome' `ivspecshort' `ctrls' if `bandwidth' & `female18', vce(cluster rkcpe)
version 10.1: margins, dydx(finishsecondary) predict(p)
qui reg finishsecondary `mainspecshort' `ctrls' if `bandwidth' & `female18' , vce(cluster rkcpe)
test passrkcpe=0
