/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Table 5
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2016
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////

// for this file you will need to install the 'rd' command
// Austin Nichols - rd
// featuring Imbens-Kalyanaraman optimal bandwidth
capture which rd
if _rc!=0 {
  ssc install rd, replace
}

local ivspecshort="(finishsecondary=passrkcpe) rkcpe int_pass_rkcpe"

local oldermale "female==0 & psdp_std98>5"
local female18 "female==1 & age_at_klps2_approximate>=18"

// Col 1
rd finishsecondary rkcpe, mbw(100)
local orig_bw1=e(w)
local bw1disp=floor(100*e(w))
di "BW `bw1disp'"
count if abs(rkcpe)<=`orig_bw1' & finishsecondary!=.

// Col 2
rd ravens_plus_vocab_standardized finishsecondary rkcpe, mbw(100)
local orig_bw2=e(w)
local bw2disp=floor(100*e(w))
di "BW `bw2disp'"
count if abs(rkcpe)<=`orig_bw2' & ravens_plus_vocab_standardized!=. & finishsecondary!=.

// Col 3
rd employed finishsecondary rkcpe if `oldermale', mbw(100)
local orig_bw3=e(w)
local bw3disp=floor(100*e(w))
di "BW `bw3disp'"
count if abs(rkcpe)<=`orig_bw3' & employed!=. & `oldermale' & finishsecondary!=.

// Col 4
local thiscmd="ivprobit employed `ivspecshort' if `oldermale' & abs(rkcpe)<=`orig_bw3', vce(cluster rkcpe)"
di "`thiscmd'"
`thiscmd'
version 10.1: margins, dydx(finishsecondary) predict(p)

// Col 5
rd self finishsecondary rkcpe if `oldermale', mbw(100)
local orig_bw4=e(w)
local bw4disp=floor(100*e(w))
di "BW `bw4disp'"
count if abs(rkcpe)<=`orig_bw4' & self_employed!=. & `oldermale' & finishsecondary!=.

// Col 6
local thiscmd="ivprobit self_employed `ivspecshort' if `oldermale' & abs(rkcpe)<=`orig_bw4', vce(cluster rkcpe)"
di "`thiscmd'"
`thiscmd'
version 10.1: margins, dydx(finishsecondary) predict(p)

// Col 7
rd pregnant_by_18 finishsecondary rkcpe if `female18', mbw(100)
local orig_bw5=e(w)
local bw5disp=floor(100*e(w))
di "BW `bw5disp'"
count if abs(rkcpe)<=`orig_bw5' & pregnant_by_18!=. & `female18' & finishsecondary!=.

// Col 8
local thiscmd="ivprobit pregnant_by_18 `ivspecshort' if `female18' & abs(rkcpe)<=`orig_bw5', vce(cluster rkcpe)"
di "`thiscmd'"
`thiscmd'
version 10.1: margins, dydx(finishsecondary) predict(p)
