/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Tables 6, 7, 8
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2008
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////



local absmax=0.8
local ivspec="(finishsecondary=passrkcpe) rkcpe int_pass_rkcpe female"
local ivspecshort="(finishsecondary=passrkcpe) rkcpe int_pass_rkcpe"
local bandwidth "abs(rkcpe)<`absmax'"
local oldermale "female==0 & psdp_std98>5"

// table 6
local outcome="ravens_plus_vocab_standardized"
reg `outcome' finishsecondary female, r
reg `outcome' finishsecondary female if rkcpe!=., vce(cluster rkcpe)
reg `outcome' finishsecondary female if `bandwidth', vce(cluster rkcpe)
reg `outcome' finishsecondary female rkcpe if `bandwidth', vce(cluster rkcpe)
ivregress 2sls `outcome' `ivspec' if `bandwidth', vce(cluster rkcpe)

// table 7
local outcome="employed"
reg `outcome' finishsecondary if `oldermale', r
reg `outcome' finishsecondary if rkcpe!=. & `oldermale', vce(cluster rkcpe)
reg `outcome' finishsecondary if `bandwidth' & `oldermale', vce(cluster rkcpe)
reg `outcome' finishsecondary rkcpe if `bandwidth' & `oldermale', vce(cluster rkcpe)
reg `outcome' finishsecondary rkcpe age_at_klps2_approximate if `bandwidth' & `oldermale', vce(cluster rkcpe)
ivregress 2sls `outcome' `ivspecshort' if `bandwidth' & `oldermale', vce(cluster rkcpe)

// table 8
// note in column 1 there is a typographical error in the published paper: sign error, coefficient should be -0.145 but is reported as 0.145
local outcome="self_employed"
reg self_employed_no_restriction finishsecondary if `oldermale', r
reg `outcome' finishsecondary if rkcpe!=. & `oldermale', vce(cluster rkcpe)
reg `outcome' finishsecondary if `bandwidth' & `oldermale', vce(cluster rkcpe)
reg `outcome' finishsecondary rkcpe if `bandwidth' & `oldermale', vce(cluster rkcpe)
reg `outcome' finishsecondary rkcpe age_at_klps2_approximate if `bandwidth' & `oldermale', vce(cluster rkcpe)
ivregress 2sls `outcome' `ivspecshort' if `bandwidth' & `oldermale', vce(cluster rkcpe)
